==> jc-1.4.0.tar.gz: javax/print/attribute/AttributeSetUtilities__24UnmodifiableDocAttributeSet.h <==
// class javax.print.attribute.AttributeSetUtilities$UnmodifiableDocAttributeSet

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 331ae21ae563dec4 javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet
// @dep_class f007178a15706c11 javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet

// header file dependencies
// @dep_header javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet

#include "javax/print/attribute/AttributeSetUtilities__24UnmodifiableAttributeSet.h"

#ifndef _JC_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet_H_
#define _JC_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_print_attribute_DocAttributeSet$object;

// Typedefs
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$sub_refs	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$sub_refs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$sub_nonrefs	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$sub_nonrefs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$refs	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$refs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$nonrefs	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$nonrefs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$object	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$object;

typedef const struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$vmethods	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$vmethods;
typedef const struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$vtable	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$vtable;
typedef const struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$vtype	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$vtype;

// Constructors
extern void _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$method$_init$bdf5415a099a64cc(_jc_env *, struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$object *, struct _jc_object *);

// Virtual methods structure
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$vmethods {
};

// Vtable
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet$vmethods	javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet;
	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$vmethods	javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet;
};

// Vtype
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$refs {
    _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$sub_refs	javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet;
    _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet$sub_refs	javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet$sub_nonrefs	javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet;
    _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$sub_nonrefs	javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet;
};

// Object instance structure
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$object {
	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$vtype	*vtype;
	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$vtype _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$class_object;

#endif	/* _JC_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet_H_ */

==> jc-1.4.6.tar.gz: javax/print/attribute/AttributeSetUtilities__24UnmodifiableDocAttributeSet.h <==
// class javax.print.attribute.AttributeSetUtilities$UnmodifiableDocAttributeSet

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 331ae21ae563dec4 javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet
// @dep_class f007178a15706c11 javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet

// header file dependencies
// @dep_header javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet

#include "javax/print/attribute/AttributeSetUtilities__24UnmodifiableAttributeSet.h"

#ifndef _JC_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet_H_
#define _JC_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_print_attribute_DocAttributeSet$object;

// Typedefs
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$sub_refs	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$sub_refs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$sub_nonrefs	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$sub_nonrefs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$refs	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$refs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$nonrefs	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$nonrefs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$object	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$object;

typedef const struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$vmethods	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$vmethods;
typedef const struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$vtable	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$vtable;
typedef const struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$vtype	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$vtype;

// Constructors
extern void _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$method$_init$bdf5415a099a64cc(_jc_env *, struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$vmethods {
};

// Vtable
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet$vmethods	javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet;
	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$vmethods	javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet;
};

// Vtype
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$refs {
    _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$sub_refs	javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet;
    _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet$sub_refs	javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet$sub_nonrefs	javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet;
    _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$sub_nonrefs	javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet;
};

// Object instance structure
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$object {
	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$vtype	*vtype;
	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$vtype _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet$class_object;

#endif	/* _JC_javax_print_attribute_AttributeSetUtilities__24UnmodifiableDocAttributeSet_H_ */
